==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ThisYearExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { ThisYearExpressionDescription } from "./ThisYearExpressionDescription";
/**
 * @hidden
 */
export let ThisYearExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class ThisYearExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (ThisYearExpressionDescriptionMetadata.a == null) {
                ThisYearExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ThisYearExpressionDescriptionMetadata.c(ThisYearExpressionDescriptionMetadata.a);
            }
            if (a.k(ThisYearExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ab(ThisYearExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            ThisYearExpressionDescriptionMetadata.b(a);
            a.ad("ThisYearExpression", () => new ThisYearExpressionDescription());
            a.ac("ThisYearExpression", ThisYearExpressionDescriptionMetadata.a);
        }
    }
    ThisYearExpressionDescriptionMetadata.$t = markType(ThisYearExpressionDescriptionMetadata, 'ThisYearExpressionDescriptionMetadata');
    ThisYearExpressionDescriptionMetadata.a = null;
    return ThisYearExpressionDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ThisYearExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { ThisYearExpressionDescription } from "./ThisYearExpressionDescription";
/**
 * @hidden
 */
export let ThisYearExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class ThisYearExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (ThisYearExpressionDescriptionMetadata.a == null) {
                ThisYearExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ThisYearExpressionDescriptionMetadata.c(ThisYearExpressionDescriptionMetadata.a);
            }
            if (a.k(ThisYearExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ac(ThisYearExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            ThisYearExpressionDescriptionMetadata.b(a);
            a.ae("ThisYearExpression", () => new ThisYearExpressionDescription());
            a.ad("ThisYearExpression", ThisYearExpressionDescriptionMetadata.a);
        }
    }
    ThisYearExpressionDescriptionMetadata.$t = markType(ThisYearExpressionDescriptionMetadata, 'ThisYearExpressionDescriptionMetadata');
    ThisYearExpressionDescriptionMetadata.a = null;
    return ThisYearExpressionDescriptionMetadata;
})();
